/* SEEDS example
   sigma has very high autocorrelation. In order to get an effective sample
   size of 1000 we need a very long run
*/
model in "seeds.bug" 
data in "seeds-data.R"
compile
inits in "seeds-init.R"
initialize
update 1000 
monitor set alpha0 , thin(10)
monitor set alpha1 , thin(10)
monitor set alpha2 , thin(10)
monitor set alpha12 , thin(10)
monitor set sigma , thin(10)
update 100000 
coda *
exit
