/* The chain can get stuck in a state where all the observations are in
   one group.
*/
model in "eyes.bug" 
data in "eyes-data.R"
compile
parameters in "eyes-inits.R"
initialize
update 1000 
monitor set P 
monitor set lambda 
monitor set sigma 
update 10000 
coda *
exit
