model in "air.bug"
data in "air-data.R"
compile
inits in "air-inits.R"
initialize
update 10000
monitor set theta0, thin(100)
monitor set theta[2], thin(100)
monitor set X, thin(100)
update 500000
coda *
exit
