/* Trivial linear regression model
*/
seed 1353
model in line.bug
data in line-data.R
compile
inits in line-inits.R
initialize
update 1000
monitor set alpha
monitor set beta
monitor set sigma 
monitor set tau 
update 10000 
coda *
exit
