/* Due to very high autocorrelation for sigma, we set a very long thinning
   interval
*/
model in "oxford.bug"
data in "oxford-data.R"
compile
inits in "oxford-init.R"
initialize
update 10000
monitor set alpha, thin(100)
monitor set beta1, thin(100)
monitor set beta2, thin(100)
monitor set sigma, thin(100)
update 100000
coda *
exit
