source("epil-data.R")
log.Base4 <- log(Base/4)
BT <- Trt * log.Base4
lm.out <- lm(BT ~ log.Base4 + Trt)
BT.resid <- residuals(lm.out)
names(BT.resid) <- NULL #FIXME: JAGS should parse names attribute
beta.Base <- coef(lm.out)["log.Base4"]
beta.Trt <- coef(lm.out)["Trt"]
names(beta.Base) <- NULL
names(beta.Trt) <- NULL
dump(c("BT.resid","beta.Base","beta.Trt"), file="BT-data.R")
