model in "cervix.bug" 
data in "cervix-data.R"
compile 
parameters in "cervix-inits.R"
initialize
update 1000
monitor set beta0C, thin(50) 
monitor set beta, thin(50) 
monitor set phi, thin(50) 
monitor set gamma1, thin(50) 
monitor set gamma2, thin(50) 
update 50000
coda *
exit
