model in "salm.bug"
data in "salm-data.R"
compile
inits in "salm-init.R"
initialize
update 1000 
monitor set alpha, thin(10)
monitor set beta, thin(10)
monitor set gamma, thin(10)
monitor set sigma, thin(10)
monitor set deviance, thin(10)
update 50000
coda *
exit
