/* SEEDS example with uniform prior on the standard deviation of the
   random effects. The autocorrelation is smaller than for other 
   parameterizations, allowing a shorter run.
*/
model in "seedsuni.bug" 
data in "seeds-data.R"
compile
inits in "seeds-init.R"
initialize
update 1000 
monitor set alpha0 , thin(10)
monitor set alpha1 , thin(10)
monitor set alpha2 , thin(10)
monitor set alpha12 , thin(10)
monitor set sigma , thin(10)
update 25000 
coda *
exit
